from distutils.core import setup

setup(
        name        =   'nesterch',
        version     =   '1.0.0',
        py_modules  =   ['nesterch'],
        author      =   'chiju',
        author_email=   'chijumelveettil@gmail.com',
        url         =   'http://nonesuch',
        description =   'A simper printer for nested lists',
    )

